require File.dirname(__FILE__) + '/../../../../test/test_helper'

class PersonTest < ActiveSupport::TestCase
  include PersonDataExport

  def setup
    @john = fast_create(Person, :name => "John Snow")
    @arya = fast_create(Person, :name => "Arya Stark")
    @joffrey = fast_create(Person, :name => "Joffrey Lannister")

    @arya.add_friend @john
    @arya.friends.reload

    @stark = fast_create(Community, :name => "House Stark")
    @stark.add_member @john
    @stark.add_admin @arya

    @lannister = fast_create(Community, :name => "House Lannister")
    @lannister.add_admin @joffrey

    @game_of_thrones = fast_create(Community, :name => "Game of Thrones")
    @game_of_thrones.add_member @john
    @game_of_thrones.add_member @arya
    @game_of_thrones.add_member @joffrey
  end

  should 'get the attributes of Joffrey Lannister' do
    attributes = person_attr_to_hash @joffrey

    assert_equal attributes["data"]["type"], "Person"
    assert_equal attributes["data"]["name"], "Joffrey Lannister"

    assert_equal attributes["articles-count"], 0

    assert_equal attributes["friends-count"], 0

    assert_equal attributes["communities-count"], 2
  end

  should 'get friendship information' do
    attributes_joffrey = person_attr_to_hash @joffrey
    attributes_arya = person_attr_to_hash @arya

    assert_equal attributes_joffrey["friends-count"], 0
    assert_equal attributes_arya["friends-count"], 1
    assert_equal attributes_arya["friends"][0]["name"], "John Snow"
  end

  should 'get softwares information' do
    @environment = Environment.default
    @environment.enabled_plugins = ['MpogSoftwarePlugin']
    @environment.add_admin(@arya)
    @environment.save

    thrones_the_game = SoftwareInfo.new
    thrones_the_game.community_id = @game_of_thrones.id
    thrones_the_game.public_software = true

    license_gpl = LicenseInfo.create(
      :version=>"CC-GPL-V2",
      :link=>"http://creativecommons.org/licenses/GPL/2.0/legalcode.pt"
    )
    thrones_the_game.license_info = license_gpl

    software = Category.create(:name => _("Software"),
                               :environment => @environment)
    categories = []
    categories << Category.create(:name => "TBS",
                                  :environment => @environment,
                                  :parent => software)
    categories << Category.create(:name => "War",
                                  :environment => @environment,
                                  :parent => software)
    thrones_the_game.community.categories << categories

    thrones_the_game.finality = "teste"
    thrones_the_game.save

    attributes = person_attr_to_hash @arya

    assert_equal attributes["softwares-count"], 1
    assert_equal attributes["softwares"][0]["name"], "Game of Thrones"
  end
end
